Aldebaran Common Library (python)
===================================

Python client library for accessing the Aldebaran API

## Install from PyPi

The official Aldebaran python client is [available on PyPi](https://pypi.python.org/pypi/aldebaran).
Install it with pip:

```bash
pip install aldebaran
```

## Running tests

```bash
export ALDEBARAN_API_KEY={{Your API key here}}
cd Test
python acl_test.py
python algo_test.py
python datadirectorytest.py
python datafile_test.py
python utiltest.py
```
